==> jenirok_0.1-3.tar.gz: jenirok-0.1/src/common/translations/fi_FI.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../gui/aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
</context>
<context>
    <name>CallListener</name>
    <message>
        <source>Searching...</source>
        <translation>Haetaan...</translation>
    </message>
    <message>
        <source>Search failed:</source>
        <translation>Haku epäonnistui:</translation>
    </message>
    <message>
        <source>Phone number was not found</source>
        <translation>Numeroa ei löytynyt</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="42"/>
        <location filename="../../gui/detailwindow.cpp" line="119"/>
        <source>Add to contacts</source>
        <translation>Lisää yhteistietoihin</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="43"/>
        <source>Copy number to clipboard</source>
        <translation>Kopioi numero leikepöydälle</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="44"/>
        <source>Call</source>
        <translation>Soita</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="45"/>
        <source>Send SMS</source>
        <translation>Lähetä SMS</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="53"/>
        <location filename="../../gui/detailwindow.cpp" line="122"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="54"/>
        <source>Street</source>
        <translation>Katu</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="55"/>
        <source>City</source>
        <translation>Kaupunki</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="57"/>
        <source>Phone number</source>
        <translation>Puhelinnumero</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <source>Unable make call</source>
        <translation>Puhelun aloittaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="123"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="154"/>
        <source>Contact was successfully added to contacts.</source>
        <translation>Yhteystieto lisättiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="190"/>
        <source>Unable to open SMS application</source>
        <translation>SMS-sovelluksen käynnistäminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <location filename="../../gui/detailwindow.cpp" line="158"/>
        <location filename="../../gui/detailwindow.cpp" line="190"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="158"/>
        <source>Unable to add contact.</source>
        <translation>Yhteystiedon lisääminen epäonnistui,</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="166"/>
        <source>Number was successfully copied to clipboard.</source>
        <translation>Numero kopioitiin onnistuneesti leikepöydälle.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="44"/>
        <source>Jenirok</source>
        <translation>Jenirok</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="50"/>
        <location filename="../../gui/mainwindow.cpp" line="115"/>
        <source>Stop daemon</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="56"/>
        <location filename="../../gui/mainwindow.cpp" line="108"/>
        <source>Start daemon</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="61"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="78"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="79"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="106"/>
        <source>Daemon was successfully stopped.</source>
        <translation>Palvelu pysäytettiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="107"/>
        <source>Unable to stop daemon.</source>
        <translation>Palvelun pysäyttäminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="113"/>
        <source>Daemon was successfully started.</source>
        <translation>Palvelu käynnistettiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="114"/>
        <source>Unable to start daemon.</source>
        <translation>Palvelun käynnistäminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="121"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="144"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="144"/>
        <source>You need to set Eniro login details in settings before using this feature.</source>
        <translation>Sinun täytyy asettaa Eniro-tunnus ja -salasana asetuksista ennen kuin voit käyttää tätä ominaisuutta.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../eniro.cpp" line="45"/>
        <source>Invalid login details</source>
        <translation>Virheellinen tunnus tai salasana</translation>
    </message>
    <message>
        <location filename="../eniro.cpp" line="46"/>
        <source>Request timed out</source>
        <translation>Pyyntö aikakatkaistiin</translation>
    </message>
</context>
<context>
    <name>ResultWindow</name>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="34"/>
        <source>Search results</source>
        <translation>Hakutulokset</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="151"/>
        <source>Unknown error</source>
        <translation>Tuntematon virhe</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="154"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="159"/>
        <source>No results found</source>
        <translation>Ei hakutuloksia</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="30"/>
        <location filename="../../gui/searchdialog.cpp" line="55"/>
        <source>Search</source>
        <translation>Haku</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="33"/>
        <source>Name/number</source>
        <translation>Numero/nimi</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="39"/>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="44"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="45"/>
        <source>Persons</source>
        <translation>Henkilöt</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="46"/>
        <source>Yellow pages</source>
        <translation>Keltaiset sivut</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="113"/>
        <source>fi</source>
        <translation>fi</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="40"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="50"/>
        <source>Eniro username</source>
        <translation>Eniro-tunnus</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="53"/>
        <source>Eniro password</source>
        <translation>Eniro-salasana</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="56"/>
        <source>Cache size (numbers)</source>
        <translation>Välimuistin koko (numeroa)</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="59"/>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="62"/>
        <source>Eniro site</source>
        <translation>Eniro-sivusto</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="79"/>
        <source>Finnish</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="82"/>
        <source>Swedish</source>
        <translation>Ruotsi</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="85"/>
        <source>Danish</source>
        <translation>Tanska</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="102"/>
        <source>Autostart</source>
        <translation>Käynnistä automaattisesti</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="104"/>
        <source>Enabled</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="105"/>
        <source>Disabled</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="108"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="154"/>
        <source>Restarting daemon...</source>
        <translation>Käynnistetään palvelu uudelleen...</translation>
    </message>
    <message numerus="yes">
        <location filename="../../gui/settingsdialog.cpp" line="178"/>
        <source>%n number(s) were deleted from cache</source>
        <translation>
            <numerusform>Poistettiin %n numero välimuistista</numerusform>
            <numerusform>Poistettiin %n numeroa välimuistista</numerusform>
        </translation>
    </message>
</context>
</TS>

==> jenirok_0.1-7.tar.gz: jenirok-0.1/src/common/translations/fi_FI.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../gui/aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
</context>
<context>
    <name>CallListener</name>
    <message>
        <source>Searching...</source>
        <translation>Haetaan...</translation>
    </message>
    <message>
        <source>Search failed:</source>
        <translation>Haku epäonnistui:</translation>
    </message>
    <message>
        <source>Phone number was not found</source>
        <translation>Numeroa ei löytynyt</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="42"/>
        <location filename="../../gui/detailwindow.cpp" line="119"/>
        <source>Add to contacts</source>
        <translation>Lisää yhteistietoihin</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="43"/>
        <source>Copy number to clipboard</source>
        <translation>Kopioi numero leikepöydälle</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="44"/>
        <source>Call</source>
        <translation>Soita</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="45"/>
        <source>Send SMS</source>
        <translation>Lähetä SMS</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="53"/>
        <location filename="../../gui/detailwindow.cpp" line="122"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="54"/>
        <source>Street</source>
        <translation>Katu</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="55"/>
        <source>City</source>
        <translation>Kaupunki</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="57"/>
        <source>Phone number</source>
        <translation>Puhelinnumero</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <source>Unable make call</source>
        <translation>Puhelun aloittaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="123"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="156"/>
        <source>Contact was successfully added to contacts.</source>
        <translation>Yhteystieto lisättiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Unable to open SMS application</source>
        <translation>SMS-sovelluksen käynnistäminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="109"/>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <location filename="../../gui/detailwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="160"/>
        <source>Unable to add contact.</source>
        <translation>Yhteystiedon lisääminen epäonnistui,</translation>
    </message>
    <message>
        <location filename="../../gui/detailwindow.cpp" line="170"/>
        <source>Number was successfully copied to clipboard.</source>
        <translation>Numero kopioitiin onnistuneesti leikepöydälle.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="44"/>
        <source>Jenirok</source>
        <translation>Jenirok</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="50"/>
        <location filename="../../gui/mainwindow.cpp" line="115"/>
        <source>Stop daemon</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="56"/>
        <location filename="../../gui/mainwindow.cpp" line="108"/>
        <source>Start daemon</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="61"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="78"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="79"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="106"/>
        <source>Daemon was successfully stopped.</source>
        <translation>Palvelu pysäytettiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="107"/>
        <source>Unable to stop daemon.</source>
        <translation>Palvelun pysäyttäminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="113"/>
        <source>Daemon was successfully started.</source>
        <translation>Palvelu käynnistettiin onnistuneesti.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="114"/>
        <source>Unable to start daemon.</source>
        <translation>Palvelun käynnistäminen ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="121"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="144"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../../gui/mainwindow.cpp" line="144"/>
        <source>You need to set Eniro login details in settings before using this feature.</source>
        <translation>Sinun täytyy asettaa Eniro-tunnus ja -salasana asetuksista ennen kuin voit käyttää tätä ominaisuutta.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../eniro.cpp" line="45"/>
        <source>Invalid login details</source>
        <translation>Virheellinen tunnus tai salasana</translation>
    </message>
    <message>
        <location filename="../eniro.cpp" line="46"/>
        <source>Request timed out</source>
        <translation>Pyyntö aikakatkaistiin</translation>
    </message>
</context>
<context>
    <name>ResultWindow</name>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="34"/>
        <source>Search results</source>
        <translation>Hakutulokset</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="166"/>
        <source>Connection to server failed</source>
        <translation>Palvelimelle yhdistäminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="169"/>
        <source>Invalid login details</source>
        <translation>Virheellinen tunnus tai salasana</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="172"/>
        <source>Request timed out</source>
        <translation>Pyyntö aikakatkaistiin</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="175"/>
        <source>Searching failed:</source>
        <translation>Haku epäonnistui:</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="179"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../gui/resultwindow.cpp" line="184"/>
        <source>No results found</source>
        <translation>Ei hakutuloksia</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="30"/>
        <location filename="../../gui/searchdialog.cpp" line="55"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="33"/>
        <source>Name/number</source>
        <translation>Numero/nimi</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="39"/>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="44"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="45"/>
        <source>Persons</source>
        <translation>Henkilöt</translation>
    </message>
    <message>
        <location filename="../../gui/searchdialog.cpp" line="46"/>
        <source>Yellow pages</source>
        <translation>Keltaiset sivut</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="113"/>
        <source>fi</source>
        <translation>fi</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="40"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="50"/>
        <source>Eniro username</source>
        <translation>Eniro-tunnus</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="53"/>
        <source>Eniro password</source>
        <translation>Eniro-salasana</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="57"/>
        <source>Cache size (numbers)</source>
        <translation>Välimuistin koko (numeroa)</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="60"/>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="63"/>
        <source>Eniro site</source>
        <translation>Eniro-sivusto</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="80"/>
        <source>Finnish</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="83"/>
        <source>Swedish</source>
        <translation>Ruotsi</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="86"/>
        <source>Danish</source>
        <translation>Tanska</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="103"/>
        <source>Autostart</source>
        <translation>Käynnistä automaattisesti</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="105"/>
        <source>Enabled</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="106"/>
        <source>Disabled</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="109"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../../gui/settingsdialog.cpp" line="155"/>
        <source>Restarting daemon...</source>
        <translation>Käynnistetään palvelu uudelleen...</translation>
    </message>
    <message numerus="yes">
        <location filename="../../gui/settingsdialog.cpp" line="179"/>
        <source>%n number(s) were deleted from cache</source>
        <translation>
            <numerusform>Poistettiin %n numero välimuistista</numerusform>
            <numerusform>Poistettiin %n numeroa välimuistista</numerusform>
        </translation>
    </message>
</context>
</TS>
